/**
 * Application dialogs provider
 * 
 * @author Pierre Hubert
 */

import { Dialog, DialogTitle, DialogContent, DialogContentText, DialogActions, Button } from "@material-ui/core";
import React from "react";

let cache : ApplicationDialogsProvider;

interface AppDiagProvState {

    // Alert dialog
    alertMessage : string,
    showAlert : boolean,

    // Confirm dialog
    confirmMessage: string,
    showConfirm: boolean,
    resolveConfirm ?: (confirmed: boolean) => void,

}

export class ApplicationDialogsProvider extends React.Component<{}, AppDiagProvState> {
    private acceptConfirm: () => void;
    private rejectConfirm: () => void;

    constructor(props: any) {
        super(props);

        this.state = {

            // Alert dialog
            alertMessage: "",
            showAlert: false,

            showConfirm: false,
            confirmMessage: "",
            resolveConfirm: undefined,
        };

        this.handleCloseAlert = this.handleCloseAlert.bind(this);

        this.acceptConfirm = this.handleCloseConfirm.bind(this, true);
        this.rejectConfirm = this.handleCloseConfirm.bind(this, false);
    }

    showAlert(message: string) {
        this.setState({
            showAlert: true,
            alertMessage: message,
        })
    }

    handleCloseAlert() {
        this.setState({showAlert: false});
    }

    showConfirm(message: string) : Promise<boolean> {
        return new Promise((res, _rej) => {
            this.setState({
                showConfirm: true,
                confirmMessage: message,
                resolveConfirm: res
            });
        });
    }

    handleCloseConfirm(accept: boolean) {
        this.setState({
            showConfirm: false
        });

        this.state.resolveConfirm && this.state.resolveConfirm(accept);
    }

    render() {
        cache = this;

        if(this.state == null)
            return(<div></div>);

        return (<div>
        
            {/* Simple alert dialog */}
            <Dialog
                open={this.state.showAlert}
                onClose={this.handleCloseAlert}
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description"
            >
                <DialogTitle id="alert-dialog-title" style={{minWidth: "300px"}}>Message</DialogTitle>
                <DialogContent>
                    <DialogContentText id="alert-dialog-description">
                    {this.state.alertMessage}
                    </DialogContentText>
                </DialogContent>
                <DialogActions>
                    <Button onClick={this.handleCloseAlert} color="default">
                        OK
                    </Button>
                </DialogActions>
            </Dialog>

            {/* Confirm dialog */}
            <Dialog
                open={this.state.showConfirm}
                onClose={this.rejectConfirm}
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description"
            >
                <DialogTitle id="alert-dialog-title" style={{minWidth: "300px"}}>Confirm action</DialogTitle>
                <DialogContent>
                    <DialogContentText id="alert-dialog-description">
                    {this.state.confirmMessage}
                    </DialogContentText>
                </DialogContent>
                <DialogActions>
                    <Button onClick={this.rejectConfirm} color="default">
                        Cancel
                    </Button>
                    <Button onClick={this.acceptConfirm} color="default">
                        Confirm
                    </Button>
                </DialogActions>
            </Dialog>
        </div>)
    }
}

export function matAlert(msg: string) {
    cache.showAlert(msg);
}

export function matConfirm(msg: string) : Promise<boolean> {
    return cache.showConfirm(msg);
}